# sdkms/v1.SecurityObjectsApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**activate_security_object**](SecurityObjectsApi.md#activate_security_object) | **POST** /crypto/v1/keys/{key-id}/activate | Transitions immediately a security object to Active state
[**agree_key**](SecurityObjectsApi.md#agree_key) | **POST** /crypto/v1/agree | Agree on a key from two other keys
[**delete_private_key**](SecurityObjectsApi.md#delete_private_key) | **DELETE** /crypto/v1/keys/{key-id}/private | Remove / Destroy private half of the asymmetric key
[**delete_security_object**](SecurityObjectsApi.md#delete_security_object) | **DELETE** /crypto/v1/keys/{key-id} | Delete a security object
[**derive_key**](SecurityObjectsApi.md#derive_key) | **POST** /crypto/v1/keys/{key-id}/derive | Derive a key from another key
[**derive_key_ex**](SecurityObjectsApi.md#derive_key_ex) | **POST** /crypto/v1/derive | Derive a key from another key
[**destroy_security_object**](SecurityObjectsApi.md#destroy_security_object) | **POST** /crypto/v1/keys/{key-id}/destroy | Destroys a security object, leaving its metadata in place
[**export_sobject_components**](SecurityObjectsApi.md#export_sobject_components) | **POST** /crypto/v1/keys/components/export | export key components
[**generate_security_object**](SecurityObjectsApi.md#generate_security_object) | **POST** /crypto/v1/keys | Generate a new security object
[**get_security_object**](SecurityObjectsApi.md#get_security_object) | **GET** /crypto/v1/keys/{key-id} | Get a specific security object
[**get_security_object_digest**](SecurityObjectsApi.md#get_security_object_digest) | **POST** /crypto/v1/keys/digest | Retrieve the digest (hash) of the value of an exportable security object
[**get_security_object_kcv**](SecurityObjectsApi.md#get_security_object_kcv) | **POST** /crypto/v1/keys/kcv | Get the key check value (KCV) of a symmetric key
[**get_security_object_value**](SecurityObjectsApi.md#get_security_object_value) | **GET** /crypto/v1/keys/{key-id}/export | Retrieve the value of an exportable security object
[**get_security_object_value_ex**](SecurityObjectsApi.md#get_security_object_value_ex) | **POST** /crypto/v1/keys/export | Retrieve the value of an exportable security object
[**get_security_objects**](SecurityObjectsApi.md#get_security_objects) | **GET** /crypto/v1/keys | Get all security objects
[**import_security_object**](SecurityObjectsApi.md#import_security_object) | **PUT** /crypto/v1/keys | Import a security object
[**import_sobject_components**](SecurityObjectsApi.md#import_sobject_components) | **POST** /crypto/v1/keys/components/import | import key components
[**persist_security_object**](SecurityObjectsApi.md#persist_security_object) | **POST** /crypto/v1/keys/persist | Persist a transient key.
[**revert_history_item**](SecurityObjectsApi.md#revert_history_item) | **PUT** /crypto/v1/keys/{key-id}/revert | Reverts a security object to a previous state
[**revoke_security_object**](SecurityObjectsApi.md#revoke_security_object) | **POST** /crypto/v1/keys/{key-id}/revoke | Transitions immediately a security object to Deactivated or Compromised state
[**rotate_security_object**](SecurityObjectsApi.md#rotate_security_object) | **POST** /crypto/v1/keys/rekey | Rotate a key.
[**update_security_object**](SecurityObjectsApi.md#update_security_object) | **PATCH** /crypto/v1/keys/{key-id} | Update a security object
[**verify_kcv**](SecurityObjectsApi.md#verify_kcv) | **POST** /crypto/v1/keys/kcv/verify | Verify that the KCV of the provided key material matches the provided KCV


# **activate_security_object**
> activate_security_object(key_id)

Transitions immediately a security object to Active state

Trigger the transition of a security object to Active state. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object

try: 
    # Transitions immediately a security object to Active state
    api_instance.activate_security_object(key_id)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->activate_security_object: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 

### Return type

void (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **agree_key**
> KeyObject agree_key(body)

Agree on a key from two other keys

This does a cryptographic key agreement operation between a public and private key. Both keys must have been generated from the same parameters (e.g. the same elliptic curve). Both keys must allow the AGREEKEY operation. The request body contains the requested properties for the new key as well as the mechanism (e.g. Diffie-Hellman) to be used to produce the key material for the new key. The output of this API should not be used directly as a cryptographic key. The target object type should be HMAC or Secret, and a key derivation procedure should be used to derive the actual key material. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.AgreeKeyRequest() # AgreeKeyRequest | Template of the agreed-upon security object

try: 
    # Agree on a key from two other keys
    api_response = api_instance.agree_key(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->agree_key: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**AgreeKeyRequest**](AgreeKeyRequest.md)| Template of the agreed-upon security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_private_key**
> delete_private_key(key_id)

Remove / Destroy private half of the asymmetric key

Removes the private portion of an asymmetric key from SDKMS. After this operation is performed, operations that require the private key, such as encryption and generating signatures, may no longer be performed. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object

try: 
    # Remove / Destroy private half of the asymmetric key
    api_instance.delete_private_key(key_id)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->delete_private_key: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 

### Return type

void (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_security_object**
> delete_security_object(key_id)

Delete a security object

Delete a specified security object.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object

try: 
    # Delete a security object
    api_instance.delete_security_object(key_id)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->delete_security_object: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 

### Return type

void (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **derive_key**
> KeyObject derive_key(key_id, body)

Derive a key from another key

This derives a key from an existing key and returns the properties of the new key. The request body contains the requested properties for the new as well as the mechanism to be used to produce the key material for the new key. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object
body = sdkms/v1.DeriveKeyRequest() # DeriveKeyRequest | Name of security object

try: 
    # Derive a key from another key
    api_response = api_instance.derive_key(key_id, body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->derive_key: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 
 **body** | [**DeriveKeyRequest**](DeriveKeyRequest.md)| Name of security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **derive_key_ex**
> KeyObject derive_key_ex(body)

Derive a key from another key

This derives a key from an existing key and returns the properties of the new key. The request body contains the requested properties for the new as well as the mechanism to be used to produce the key material for the new key. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.DeriveKeyRequestEx() # DeriveKeyRequestEx | Name of security object

try: 
    # Derive a key from another key
    api_response = api_instance.derive_key_ex(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->derive_key_ex: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**DeriveKeyRequestEx**](DeriveKeyRequestEx.md)| Name of security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **destroy_security_object**
> destroy_security_object(key_id)

Destroys a security object, leaving its metadata in place

Destroys a security object. Objects in the `Destroyed` state cannot be used in any cryptographic operation. Their metadata however, remains present. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object

try: 
    # Destroys a security object, leaving its metadata in place
    api_instance.destroy_security_object(key_id)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->destroy_security_object: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 

### Return type

void (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **export_sobject_components**
> ExportComponentsResponse export_sobject_components(body)

export key components



### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.ExportSobjectComponentsRequest() # ExportSobjectComponentsRequest | Request to export a security object componsnts

try: 
    # export key components
    api_response = api_instance.export_sobject_components(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->export_sobject_components: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**ExportSobjectComponentsRequest**](ExportSobjectComponentsRequest.md)| Request to export a security object componsnts | 

### Return type

[**ExportComponentsResponse**](ExportComponentsResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **generate_security_object**
> KeyObject generate_security_object(body)

Generate a new security object

Generate a new security object (such as an RSA key pair or an AES key) of the requested size or elliptic curve. <br> By default, all key operations except for Export that are implemented for that type of key will be enabled. These may be overridden by requesting specific operations in the key creation request. <br> Objects of type Opaque may not be generated with this API. They must be imported via the importSecurityObject API. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.SobjectRequest() # SobjectRequest | Request to create, update, or import security object

try: 
    # Generate a new security object
    api_response = api_instance.generate_security_object(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->generate_security_object: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**SobjectRequest**](SobjectRequest.md)| Request to create, update, or import security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_security_object**
> KeyObject get_security_object(key_id, view=view, show_destroyed=show_destroyed, show_deleted=show_deleted)

Get a specific security object

Get the details of a particular security object. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object
view = 'json' # str | The encoding the value of an opaque object or certificate (optional) (default to json)
show_destroyed = false # bool | Whether security objects in the `Destroyed` state should be returned (optional) (default to false)
show_deleted = true # bool | Whether security objects in the `Deleted` state should be returned (optional)

try: 
    # Get a specific security object
    api_response = api_instance.get_security_object(key_id, view=view, show_destroyed=show_destroyed, show_deleted=show_deleted)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->get_security_object: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 
 **view** | **str**| The encoding the value of an opaque object or certificate | [optional] [default to json]
 **show_destroyed** | **bool**| Whether security objects in the &#x60;Destroyed&#x60; state should be returned | [optional] [default to false]
 **show_deleted** | **bool**| Whether security objects in the &#x60;Deleted&#x60; state should be returned | [optional] 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_security_object_digest**
> DigestResponse get_security_object_digest(body)

Retrieve the digest (hash) of the value of an exportable security object

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.ObjectDigestRequest() # ObjectDigestRequest | Object digest request

try: 
    # Retrieve the digest (hash) of the value of an exportable security object
    api_response = api_instance.get_security_object_digest(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->get_security_object_digest: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**ObjectDigestRequest**](ObjectDigestRequest.md)| Object digest request | 

### Return type

[**DigestResponse**](DigestResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_security_object_kcv**
> KeyCheckValueResponse get_security_object_kcv(body)

Get the key check value (KCV) of a symmetric key

Get the key check value (KCV) of a symmetric key

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.SobjectDescriptor() # SobjectDescriptor | Request to export a security object

try: 
    # Get the key check value (KCV) of a symmetric key
    api_response = api_instance.get_security_object_kcv(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->get_security_object_kcv: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**SobjectDescriptor**](SobjectDescriptor.md)| Request to export a security object | 

### Return type

[**KeyCheckValueResponse**](KeyCheckValueResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_security_object_value**
> KeyObject get_security_object_value(key_id)

Retrieve the value of an exportable security object

Get the details and value of a particular exportable security object. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object

try: 
    # Retrieve the value of an exportable security object
    api_response = api_instance.get_security_object_value(key_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->get_security_object_value: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_security_object_value_ex**
> KeyObject get_security_object_value_ex(body)

Retrieve the value of an exportable security object

Get the details and value of a particular exportable security object. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.SobjectDescriptor() # SobjectDescriptor | Request to export a security object

try: 
    # Retrieve the value of an exportable security object
    api_response = api_instance.get_security_object_value_ex(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->get_security_object_value_ex: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**SobjectDescriptor**](SobjectDescriptor.md)| Request to export a security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_security_objects**
> list[KeyObject] get_security_objects(name=name, group_id=group_id, creator=creator, sort=sort, compliant_with_policies=compliant_with_policies, start=start, limit=limit, offset=offset, show_destroyed=show_destroyed, show_deleted=show_deleted)

Get all security objects

Return detailed information about the security objects stored in Fortanix SDKMS. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
name = 'name_example' # str | Only retrieve the security object with this name. (optional)
group_id = 'group_id_example' # str | Only retrieve security objects in the specified group. (optional)
creator = 'creator_example' # str | Only retrieve security objects created by the user or application with the specified id. (optional)
sort = 'sort_example' # str | This specifies the property (`kid` or `name`) and order (ascending or descending) with which to sort the security objects. By default, security objects are sorted by `kid` in ascending order. The syntax is \"<property>:[asc|desc]\" (e.g. \"kid:desc\") or just \"<property>\" (ascending order by default).  (optional)
compliant_with_policies = true # bool | Whether this security object is compliant with cryptographic policies or not. (optional)
start = 'start_example' # str | If provided, this must be a value of the property specified in `sort`. Returned security objects will begin just above or just below this value (for asc/desc order resp.).  (optional)
limit = 56 # int | Maximum number of security objects to return. If not provided, the limit is 100. (optional)
offset = 56 # int | Number of security objects past `start` to skip. (optional)
show_destroyed = true # bool | Whether security objects in the `Destroyed` state should be returned (optional)
show_deleted = true # bool | Whether security objects in the `Deleted` state should be returned (optional)

try: 
    # Get all security objects
    api_response = api_instance.get_security_objects(name=name, group_id=group_id, creator=creator, sort=sort, compliant_with_policies=compliant_with_policies, start=start, limit=limit, offset=offset, show_destroyed=show_destroyed, show_deleted=show_deleted)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->get_security_objects: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **str**| Only retrieve the security object with this name. | [optional] 
 **group_id** | **str**| Only retrieve security objects in the specified group. | [optional] 
 **creator** | **str**| Only retrieve security objects created by the user or application with the specified id. | [optional] 
 **sort** | **str**| This specifies the property (&#x60;kid&#x60; or &#x60;name&#x60;) and order (ascending or descending) with which to sort the security objects. By default, security objects are sorted by &#x60;kid&#x60; in ascending order. The syntax is \&quot;&lt;property&gt;:[asc|desc]\&quot; (e.g. \&quot;kid:desc\&quot;) or just \&quot;&lt;property&gt;\&quot; (ascending order by default).  | [optional] 
 **compliant_with_policies** | **bool**| Whether this security object is compliant with cryptographic policies or not. | [optional] 
 **start** | **str**| If provided, this must be a value of the property specified in &#x60;sort&#x60;. Returned security objects will begin just above or just below this value (for asc/desc order resp.).  | [optional] 
 **limit** | **int**| Maximum number of security objects to return. If not provided, the limit is 100. | [optional] 
 **offset** | **int**| Number of security objects past &#x60;start&#x60; to skip. | [optional] 
 **show_destroyed** | **bool**| Whether security objects in the &#x60;Destroyed&#x60; state should be returned | [optional] 
 **show_deleted** | **bool**| Whether security objects in the &#x60;Deleted&#x60; state should be returned | [optional] 

### Return type

[**list[KeyObject]**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **import_security_object**
> KeyObject import_security_object(body)

Import a security object

Import a security object into SDKMS. <br> By default, all key operations except that are implemented for that type of key will be enabled. These may be overridden by requesting specific operations in the key import request. <br> For symmetric and asymmetric keys, value is base64-encoding of the key material in DER format. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.SobjectRequest() # SobjectRequest | Request to create, update, or import security object

try: 
    # Import a security object
    api_response = api_instance.import_security_object(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->import_security_object: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**SobjectRequest**](SobjectRequest.md)| Request to create, update, or import security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **import_sobject_components**
> KeyObject import_sobject_components(body)

import key components



### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.ImportSobjectComponentsRequest() # ImportSobjectComponentsRequest | Request to import a security object componsnts

try: 
    # import key components
    api_response = api_instance.import_sobject_components(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->import_sobject_components: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**ImportSobjectComponentsRequest**](ImportSobjectComponentsRequest.md)| Request to import a security object componsnts | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **persist_security_object**
> KeyObject persist_security_object(body)

Persist a transient key.

This API copies a transient key into a persisted security object in SDKMS. If the transient key's origin is \"FortanixHSM\", the origin of the persisted key will be \"Transient\". If the transient key's origin is \"External\", the origin of the persisted key will be \"External\". 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.PersistTransientKeyRequest() # PersistTransientKeyRequest | Persist transient key request

try: 
    # Persist a transient key.
    api_response = api_instance.persist_security_object(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->persist_security_object: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**PersistTransientKeyRequest**](PersistTransientKeyRequest.md)| Persist transient key request | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **revert_history_item**
> revert_history_item(key_id, body)

Reverts a security object to a previous state

When a Key Undo Policy is in place, security objects maintain a list of history items. Using this API endpoint, clients may revert the security object to a previous (non-expired) history item. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object
body = sdkms/v1.SobjectRequest() # SobjectRequest | Request to create, update, or import security object

try: 
    # Reverts a security object to a previous state
    api_instance.revert_history_item(key_id, body)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->revert_history_item: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 
 **body** | [**SobjectRequest**](SobjectRequest.md)| Request to create, update, or import security object | 

### Return type

void (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **revoke_security_object**
> revoke_security_object(key_id, body)

Transitions immediately a security object to Deactivated or Compromised state

Trigger the transition of a security object to Deactivated or Compromised state depending on the RevocationReason Code. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object
body = sdkms/v1.RevocationReason() # RevocationReason | Reason to revoke a security object

try: 
    # Transitions immediately a security object to Deactivated or Compromised state
    api_instance.revoke_security_object(key_id, body)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->revoke_security_object: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 
 **body** | [**RevocationReason**](RevocationReason.md)| Reason to revoke a security object | 

### Return type

void (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **rotate_security_object**
> KeyObject rotate_security_object(body)

Rotate a key.

Rotate an existing security object.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.SobjectRequest() # SobjectRequest | Request to create, update, or import security object

try: 
    # Rotate a key.
    api_response = api_instance.rotate_security_object(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->rotate_security_object: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**SobjectRequest**](SobjectRequest.md)| Request to create, update, or import security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_security_object**
> KeyObject update_security_object(key_id, body)

Update a security object

Update the properties of a security object. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object
body = sdkms/v1.SobjectRequest() # SobjectRequest | Request to create, update, or import security object

try: 
    # Update a security object
    api_response = api_instance.update_security_object(key_id, body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->update_security_object: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 
 **body** | [**SobjectRequest**](SobjectRequest.md)| Request to create, update, or import security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **verify_kcv**
> VerifyKcvResponse verify_kcv(body)

Verify that the KCV of the provided key material matches the provided KCV

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SecurityObjectsApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.VerifyKcvRequest() # VerifyKcvRequest | Verify KCV request

try: 
    # Verify that the KCV of the provided key material matches the provided KCV
    api_response = api_instance.verify_kcv(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SecurityObjectsApi->verify_kcv: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**VerifyKcvRequest**](VerifyKcvRequest.md)| Verify KCV request | 

### Return type

[**VerifyKcvResponse**](VerifyKcvResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

